.. _install-plugin-registry:

===============
Plugin Registry
===============

.. note::

   Currently, Horizon plugins are responsible for their own compatibility.
   Check the individual repos for information on support.

.. list-table::
   :header-rows: 1

   * - Plugin
     - Repository
     - Bug Tracker
   * - BGPVPN Dashboard
     - :opendev-repo:`openstack/networking-bgpvpn`
     - :launchpad:`bgpvpn`
   * - Blazar Dashboard
     - :opendev-repo:`openstack/blazar-dashboard`
     - :launchpad:`blazar`
   * - Cloudkitty Dashboard
     - :opendev-repo:`openstack/cloudkitty-dashboard`
     - :launchpad:`cloudkitty`
   * - Congress Dashboard
     - :opendev-repo:`openstack/congress-dashboard`
     - :launchpad:`congress`
   * - Designate Dashboard
     - :opendev-repo:`openstack/designate-dashboard`
     - :launchpad:`designate-dashboard`
   * - Group Based Policy UI
     - :opendev-repo:`x/group-based-policy-ui`
     - :launchpad:`group-based-policy-ui`
   * - Freezer Web UI
     - :opendev-repo:`openstack/freezer-web-ui`
     - :launchpad:`freezer`
   * - Heat Dashboard
     - :opendev-repo:`openstack/heat-dashboard`
     - :storyboard:`openstack/heat-dashboard`
   * - Ironic UI
     - :opendev-repo:`openstack/ironic-ui`
     - :launchpad:`ironic-ui`
   * - Karbor Dashboard
     - :opendev-repo:`openstack/karbor-dashboard`
     - :launchpad:`karbor-dashboard`
   * - Magnum UI
     - :opendev-repo:`openstack/magnum-ui`
     - :launchpad:`magnum-ui`
   * - Manila UI
     - :opendev-repo:`openstack/manila-ui`
     - :launchpad:`manila-ui`
   * - Mistral Dashboard
     - :opendev-repo:`openstack/mistral-dashboard`
     - :launchpad:`mistral`
   * - Monasca UI
     - :opendev-repo:`openstack/monasca-ui`
     - :launchpad:`monasca`
   * - Murano Dashboard
     - :opendev-repo:`openstack/murano-dashboard`
     - :launchpad:`murano`
   * - Neutron FWaaS Dashboard
     - :opendev-repo:`openstack/neutron-fwaas-dashboard`
     - :launchpad:`neutron-fwaas-dashboard`
   * - Neutron VPNaaS Dashboard
     - :opendev-repo:`openstack/neutron-vpnaas-dashboard`
     - :launchpad:`neutron-vpnaas-dashboard`
   * - Octavia Dashboard
     - :opendev-repo:`openstack/octavia-dashboard`
     - :storyboard:`openstack/octavia-dashboard`
   * - Sahara Dashboard
     - :opendev-repo:`openstack/sahara-dashboard`
     - :storyboard:`openstack/sahara-dashboard`
   * - Searchlight UI
     - :opendev-repo:`openstack/searchlight-ui`
     - :storyboard:`openstack/searchlight-ui`
   * - Senlin Dashboard
     - :opendev-repo:`openstack/senlin-dashboard`
     - :launchpad:`senlin-dashboard`
   * - Solum Dashboard
     - :opendev-repo:`openstack/solum-dashboard`
     - :launchpad:`solum`
   * - Tacker UI
     - :opendev-repo:`openstack/tacker-horizon`
     - :launchpad:`tacker`
   * - Trove Dashboard
     - :opendev-repo:`openstack/trove-dashboard`
     - :launchpad:`trove-dashboard`
   * - Vitrage Dashboard
     - :opendev-repo:`openstack/vitrage-dashboard`
     - :storyboard:`openstack/vitrage-dashboard`
   * - Watcher Dashboard
     - :opendev-repo:`openstack/watcher-dashboard`
     - :launchpad:`watcher-dashboard`
   * - Zaqar UI
     - :opendev-repo:`openstack/zaqar-ui`
     - :launchpad:`zaqar-ui`
   * - Zun UI
     - :opendev-repo:`openstack/zun-ui`
     - :launchpad:`zun-ui`
